PathEvent

Enum PathEvent 

#[non_exhaustive]
pub enum PathEvent {
#[non_exhaustive]
Opened { id: PathId, remote_addr: TransportAddr, local_addr: LocalTransportAddr, },
#[non_exhaustive]
Closed { id: PathId, remote_addr: TransportAddr, local_addr: LocalTransportAddr, last_stats: Box<PathStats>, },
#[non_exhaustive]
Selected { id: PathId, remote_addr: TransportAddr, local_addr: LocalTransportAddr, },
#[non_exhaustive]
Lagged { missed: u64, }, }
Lifecycle notifications for a transmission paths in a connection.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


#[non_exhaustive]
Opened

A new network path was opened.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
id: PathId

Path identifier.

remote_addr: TransportAddr

Remote transport address.

local_addr: LocalTransportAddr

Local address of the path, if known.



#[non_exhaustive]
Closed

A network path was closed.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
id: PathId

Path identifier.

remote_addr: TransportAddr

Remote transport address.

local_addr: LocalTransportAddr

Local address of the path, if known.

last_stats: Box<PathStats>

Path statistics captured at close time.



#[non_exhaustive]
Selected

This path was selected for transmission of application data.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
id: PathId

Path identifier of the newly selected path.

remote_addr: TransportAddr

Remote transport address of the newly selected path.

local_addr: LocalTransportAddr

The local address of the newly selected path, if known.



#[non_exhaustive]
Lagged

Events were dropped before the subscriber received them.

Yielded when the subscriber does not poll the stream fast enough to keep up with the writer. The current set of open paths and the selected path remain accessible via Connection::paths.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
missed: u64

Number of events dropped since the last delivered event.