NetReportConfig

Struct NetReportConfig 

#[non_exhaustive]
pub struct NetReportConfig { pub https_probes: bool, pub captive_portal_check: bool, }
Configuration for the net report component.

Controls which probes and checks are performed when generating network reports. All options default to true.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
https_probes: bool

Run HTTPS latency probes against relay servers.

HTTPS latency probes perform an empty HTTPS GET request to each configured relay server and measure latency.

They are performed in addition to the QUIC address discovery (QAD) probes. In networks that do not allow QUIC traffic, they are the only way to detect relay latencies and thus the preferred relay.

Disabling them is harmless on networks that do allow QUIC traffic, but will completely prevent finding the home relay on networks that do block QUIC.

captive_portal_check: bool

Check for captive portals when generating the first report.

This is done by accessing a well-known URL that is available on each relay server, /generate_204. If a GET request to this URL returns anything else but a 204 No Content response, we assume we are behind a captive portal.

When we have detected that we are behind a captive portal, we try to contact the relay servers more frequently in case the captive portal status changes.

Implementations



impl NetReportConfig

pub fn minimal() -> NetReportConfig

Creates a minimal configuration that disables all optional probes and checks.