Struct PortmapMetrics
pub struct PortmapMetrics {
pub probes_started: Counter,
pub local_port_updates: Counter,
pub mapping_attempts: Counter,
pub mapping_failures: Counter,
pub external_address_updated: Counter,
pub upnp_probes: Counter,
pub upnp_probes_failed: Counter,
pub upnp_available: Counter,
pub upnp_gateway_updated: Counter,
pub pcp_probes: Counter,
pub pcp_available: Counter,
}Expand description
Enum of metrics for the module
Fields
probes_started: CounterNumber of probing tasks started.
local_port_updates: CounterNumber of updates to the local port.
mapping_attempts: CounterNumber of mapping tasks started.
mapping_failures: CounterNumber of failed mapping tasks.
external_address_updated: CounterNumber of times the external address obtained via port mapping was updated.
upnp_probes: CounterNumber of UPnP probes executed.
upnp_probes_failed: CounterNumber of failed Upnp probes.
upnp_available: CounterNumber of UPnP probes that found it available.
upnp_gateway_updated: CounterNumber of UPnP probes that resulted in a gateway different to the previous one,
pcp_probes: CounterNumber of PCP probes executed.
pcp_available: CounterNumber of PCP probes that found it available.