Struct Tstatfs
pub struct Tstatfs {
pub fid: u32,
}Expand description
statfs – get file system information
size[4] Tstatfs tag[2] fid[4]
size[4] Rstatfs tag[2] type[4] bsize[4] blocks[8] bfree[8] bavail[8]
files[8] ffree[8] fsid[8] namelen[4]statfs is used to request file system information of the file system containing fid. The Rstatfs response corresponds to the fields returned by the statfs(2) system call.
Fields
fid: u32Trait Implementations