Struct Tlcreate
pub struct Tlcreate {
pub fid: u32,
pub name: String,
pub flags: u32,
pub mode: u32,
pub gid: u32,
}Expand description
lcreate – create a file
size[4] Tlcreate tag[2] fid[4] name[s] flags[4] mode[4] gid[4]
size[4] Rlcreate tag[2] qid[13] iounit[4]lcreate creates a new file name in the directory represented by fid and prepares it for I/O. The flags field has the standard open(2) values.
Fields
fid: u32name: Stringflags: u32mode: u32gid: u32Trait Implementations