Struct Txattrwalk
pub struct Txattrwalk {
pub fid: u32,
pub newfid: u32,
pub name: String,
}Expand description
xattrwalk – walk extended attributes
size[4] Txattrwalk tag[2] fid[4] newfid[4] name[s]
size[4] Rxattrwalk tag[2] size[8]xattrwalk gets a new fid pointing to the extended attribute directory of the file represented by fid.
Fields
fid: u32newfid: u32name: StringTrait Implementations
impl Debug for Txattrwalk
impl Debug for Txattrwalk
impl WireFormat for Txattrwalk
impl WireFormat for Txattrwalk