Struct FieldSet
pub struct FieldSet { /* private fields */ }Expand description
Describes the fields present on a span.
Equality
In well-behaved applications, two FieldSets initialized with equal
callsite identifiers will have identical fields. Consequently, in release
builds, FieldSet::eq only checks that its arguments have equal
callsites. However, the equality of field names is checked in debug builds.
Implementations
impl FieldSet
impl FieldSet
pub const fn new(
names: &'static [&'static str],
callsite: Identifier,
) -> FieldSet
pub const fn new( names: &'static [&'static str], callsite: Identifier, ) -> FieldSet
Constructs a new FieldSet with the given array of field names and callsite.
pub fn field<Q>(&self, name: &Q) -> Option<Field>
pub fn field<Q>(&self, name: &Q) -> Option<Field>
Returns the Field named name, or None if no such field exists.
pub fn contains(&self, field: &Field) -> bool
pub fn contains(&self, field: &Field) -> bool
Returns true if self contains the given field.
Note: Iffieldshares a name with a field in thisFieldSet, but was created by aFieldSetwith a different callsite, thisFieldSetdoes not contain it. This is so that if two separate span callsites define a field named "foo", theFieldcorresponding to "foo" for each of those callsites are not equivalent.