Struct Frame
pub struct Frame<T>where
T: Framer,{
pub tag: u16,
pub msg: T,
}Fields
tag: u16msg: TTrait Implementations
impl<'de, T> Deserialize<'de> for Frame<T>where
T: Framer + Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Frame<T>where
T: Framer + Deserialize<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Frame<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Frame<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<T> Serialize for Frame<T>
impl<T> Serialize for Frame<T>
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<P> Sink<Frame<<P as Protocol>::Request>> for IrohTransport<P>
impl<P> Sink<Frame<<P as Protocol>::Request>> for IrohTransport<P>
fn poll_ready(
self: Pin<&mut IrohTransport<P>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
fn poll_ready( self: Pin<&mut IrohTransport<P>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
Attempts to prepare the
Sink to receive a value. Read morefn start_send(
self: Pin<&mut IrohTransport<P>>,
item: Frame<<P as Protocol>::Request>,
) -> Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>
fn start_send( self: Pin<&mut IrohTransport<P>>, item: Frame<<P as Protocol>::Request>, ) -> Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>
Begin the process of sending a value to the sink.
Each call to this function must be preceded by a successful call to
poll_ready which returned Poll::Ready(Ok(())). Read morefn poll_flush(
self: Pin<&mut IrohTransport<P>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
fn poll_flush( self: Pin<&mut IrohTransport<P>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
Flush any remaining output from this sink. Read more
fn poll_close(
self: Pin<&mut IrohTransport<P>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
fn poll_close( self: Pin<&mut IrohTransport<P>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <IrohTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
Flush any remaining output and close this sink, if necessary. Read more
impl<P> Sink<Frame<<P as Protocol>::Request>> for QuicTransport<P>
impl<P> Sink<Frame<<P as Protocol>::Request>> for QuicTransport<P>
fn poll_ready(
self: Pin<&mut QuicTransport<P>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
fn poll_ready( self: Pin<&mut QuicTransport<P>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
Attempts to prepare the
Sink to receive a value. Read morefn start_send(
self: Pin<&mut QuicTransport<P>>,
item: Frame<<P as Protocol>::Request>,
) -> Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>
fn start_send( self: Pin<&mut QuicTransport<P>>, item: Frame<<P as Protocol>::Request>, ) -> Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>
Begin the process of sending a value to the sink.
Each call to this function must be preceded by a successful call to
poll_ready which returned Poll::Ready(Ok(())). Read morefn poll_flush(
self: Pin<&mut QuicTransport<P>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
fn poll_flush( self: Pin<&mut QuicTransport<P>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
Flush any remaining output from this sink. Read more
fn poll_close(
self: Pin<&mut QuicTransport<P>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
fn poll_close( self: Pin<&mut QuicTransport<P>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <QuicTransport<P> as Sink<Frame<<P as Protocol>::Request>>>::Error>>
Flush any remaining output and close this sink, if necessary. Read more
impl<T> WireFormat for Frame<T>where
T: Framer,
impl<T> WireFormat for Frame<T>where
T: Framer,