Rversion

Struct Rversion 

pub struct Rversion {
    pub msize: u32,
    pub version: String,
}
version – negotiate protocol version

size[4] Rversion tag[2] msize[4] version[s]

version establishes the msize, which is the maximum message size inclusive of the size value that can be handled by both client and server.

It also establishes the protocol version. For 9P2000.L version must be the string 9P2000.L.

See the Plan 9 manual page for version(5).

Fields

msize: u32version: String