Struct NoSubscriber
pub struct NoSubscriber(/* private fields */);Expand description
A no-op Subscriber.
NoSubscriber implements the Subscriber trait by never being enabled,
never being interested in any callsite, and dropping all spans and events.
Implementations
impl NoSubscriber
impl NoSubscriber
pub const fn new() -> NoSubscriber
pub const fn new() -> NoSubscriber
Returns a new NoSubscriber.