Struct DnsAddressLookup
pub struct DnsAddressLookup { /* private fields */ }Expand description
DNS endpoint discovery
When asked to resolve a EndpointId, this service performs a lookup in the Domain Name System (DNS).
It uses the Endpoint’s DNS resolver to query for TXT records under the domain
_iroh.<z32-endpoint-id>.<origin-domain>:
_iroh: is the record name<z32-endpoint-id>is theEndpointIdencoded inz-base-32format<origin-domain>is the endpoint origin domain as set inDnsAddressLookup::builder.
Each TXT record returned from the query is expected to contain a string in the format <name>=<value>.
If a TXT record contains multiple character strings, they are concatenated first.
The supported attributes are:
relay=<url>: The URL of the home relay server of the endpoint
The DNS resolver defaults to using the nameservers configured on the host system, but can be changed
with crate::endpoint::Builder::dns_resolver.
Implementations
impl DnsAddressLookup
impl DnsAddressLookup
pub fn builder(origin_domain: String) -> DnsAddressLookupBuilder
pub fn builder(origin_domain: String) -> DnsAddressLookupBuilder
Creates a DnsAddressLookupBuilder that implements IntoAddressLookup.
pub fn n0_dns() -> DnsAddressLookupBuilder
pub fn n0_dns() -> DnsAddressLookupBuilder
Creates a new DNS discovery using the iroh.link domain.
This uses the N0_DNS_ENDPOINT_ORIGIN_PROD domain.
Usage during tests
For testing it is possible to use the N0_DNS_ENDPOINT_ORIGIN_STAGING domain
with DnsAddressLookup::builder. This would then use a hosted staging discovery
service for testing purposes.