PkarrResolver

Struct PkarrResolver 

pub struct PkarrResolver { /* private fields */ }
Resolver of address lookup information from a pkarr relay.

The resolver uses HTTP to query address lookup information from a pkarr relay server, see the module docs for details.

This implements the AddressLookup trait to be used as an address lookup service. Note that it only resolves address lookup information, for the corresponding publisher use the PkarrPublisher together with ConcurrentAddressLookup.

Implementations



impl PkarrResolver

pub fn builder(pkarr_relay: Url) -> PkarrResolverBuilder

Creates a new resolver builder using the pkarr relay server at the URL.

The builder implements IntoAddressLookup.

pub fn n0_dns() -> PkarrResolverBuilder

Creates a pkarr resolver builder which uses the number 0 pkarr relay server.

This uses the pkarr relay server operated by number 0 at N0_DNS_PKARR_RELAY_PROD.

When running with the environment variable IROH_FORCE_STAGING_RELAYS set to any non empty value N0_DNS_PKARR_RELAY_STAGING server is used instead.