Struct Accepting
pub struct Accepting { /* private fields */ }Expand description
In-progress connection attempt future
Implementations
impl Accepting
impl Accepting
pub fn into_0rtt(self) -> Connection<IncomingZeroRtt>
pub fn into_0rtt(self) -> Connection<IncomingZeroRtt>
Converts this Accepting into a 0-RTT or 0.5-RTT connection at the cost of weakened
security.
Returns a IncomingZeroRttConnection, which represents an incoming 0-RTT or 0.5-RTT connection.
If the connection was initiated with 0-RTT by the remote endpoint, the local endpoint might accept the 0-RTT attempt, allowing the local endpoint to receive application streams and data before the handshake finishes.
Otherwise this will enable 0.5-RTT, allowing the IncomingZeroRttConnection to open streams and send
data before the handshake finishes.
Security
Transmitted 0-RTT data from the client is vulnerable to replay attacks, and should therefore never invoke non-idempotent operations.
Transmission of 0.5-RTT data from the server may be sent before TLS client authentication has occurred, and should therefore not be used to send data for which client authentication is required.
You can use RecvStream::is_0rtt to check whether a stream has been opened in 0-RTT
and thus whether parts of the stream are operating under this reduced security level.
See also documentation for Connecting::into_0rtt.
pub async fn handshake_data(&mut self) -> Result<Box<dyn Any>, ConnectionError>
pub async fn handshake_data(&mut self) -> Result<Box<dyn Any>, ConnectionError>
Parameters negotiated during the handshake