Struct PublicKey
pub struct PublicKey(/* private fields */);Expand description
A public key.
The key itself is stored as the CompressedEdwards y coordinate of the public key
It is verified to decompress into a valid key when created.
Implementations
impl PublicKey
impl PublicKey
pub const LENGTH: usize = ed25519_dalek::PUBLIC_KEY_LENGTH
pub const LENGTH: usize = ed25519_dalek::PUBLIC_KEY_LENGTH
The length of an ed25519 PublicKey, in bytes.
pub fn from_bytes(bytes: &[u8; 32]) -> Result<PublicKey, KeyParsingError>
pub fn from_bytes(bytes: &[u8; 32]) -> Result<PublicKey, KeyParsingError>
Construct a PublicKey from a slice of bytes.
Warning
This will return a SignatureError if the bytes passed into this method do not represent
a valid ed25519_dalek curve point. Will never fail for bytes return from Self::as_bytes.
See [VerifyingKey::from_bytes] for details.