Trait WireFormat
pub trait WireFormat: Send {
// Required methods
fn byte_size(&self) -> u32;
fn encode<W>(&self, writer: &mut W) -> Result<(), Error>
where W: Write,
Self: Sized;
fn decode<R>(reader: &mut R) -> Result<Self, Error>
where R: Read,
Self: Sized;
}Expand description
A type that can be encoded on the wire using the 9P protocol.
Required Methods
Implementations on Foreign Types
impl WireFormat for IpAddr
impl WireFormat for IpAddr
impl WireFormat for SocketAddr
impl WireFormat for SocketAddr
impl WireFormat for bool
impl WireFormat for bool
impl WireFormat for f32
impl WireFormat for f32
impl WireFormat for f64
impl WireFormat for f64
impl WireFormat for i16
impl WireFormat for i16
impl WireFormat for i32
impl WireFormat for i32
impl WireFormat for i64
impl WireFormat for i64
impl WireFormat for i128
impl WireFormat for i128
impl WireFormat for isize
impl WireFormat for isize
impl WireFormat for u8
impl WireFormat for u8
impl WireFormat for u16
impl WireFormat for u16
impl WireFormat for u32
impl WireFormat for u32
impl WireFormat for u64
impl WireFormat for u64
impl WireFormat for u128
impl WireFormat for u128
impl WireFormat for ()
impl WireFormat for ()
impl WireFormat for usize
impl WireFormat for usize
impl WireFormat for String
impl WireFormat for String
impl WireFormat for Ipv4Addr
impl WireFormat for Ipv4Addr
impl WireFormat for Ipv6Addr
impl WireFormat for Ipv6Addr
impl WireFormat for SocketAddrV4
impl WireFormat for SocketAddrV4
impl WireFormat for SocketAddrV6
impl WireFormat for SocketAddrV6
impl WireFormat for SystemTime
Implement WireFormat for SystemTime, must be used with care as it can lead to overflow errors on Windows.
impl WireFormat for SystemTime
Implement WireFormat for SystemTime, must be used with care as it can lead to overflow errors on Windows.
impl WireFormat for Url
impl WireFormat for Url
impl WireFormat for Error
r[impl jetstream.error.v2.wireformat]
r[impl jetstream.error.v2.wireformat.message]
r[impl jetstream.error.v2.wireformat.code]
r[impl jetstream.error.v2.wireformat.backtrace]
impl WireFormat for Error
r[impl jetstream.error.v2.wireformat] r[impl jetstream.error.v2.wireformat.message] r[impl jetstream.error.v2.wireformat.code] r[impl jetstream.error.v2.wireformat.backtrace]
impl WireFormat for NodeAddr
impl WireFormat for NodeAddr
impl WireFormat for NodeId
impl WireFormat for NodeId
impl WireFormat for Rerror
impl WireFormat for Rerror
impl WireFormat for Rlerror
impl WireFormat for Rlerror
impl WireFormat for TlsCert
impl WireFormat for TlsCert
impl WireFormat for TlsPeer
impl WireFormat for TlsPeer
impl WireFormat for TransportAddr
Available on crate feature iroh only.
impl WireFormat for TransportAddr
Available on crate feature
iroh only.impl WireFormat for WebCredentials
impl WireFormat for WebCredentials
impl<K, V> WireFormat for BTreeMap<K, V>
Available on crate feature std only.
impl<K, V> WireFormat for BTreeMap<K, V>
Available on crate feature
std only.impl<T> WireFormat for Option<T>where
T: WireFormat,
impl<T> WireFormat for Option<T>where
T: WireFormat,
impl<T> WireFormat for Box<T>where
T: WireFormat,
impl<T> WireFormat for Box<T>where
T: WireFormat,
impl<T> WireFormat for Vec<T>where
T: WireFormat,
impl<T> WireFormat for Vec<T>where
T: WireFormat,
impl<T> WireFormat for PhantomData<T>where
T: WireFormat,
impl<T> WireFormat for PhantomData<T>where
T: WireFormat,
impl<V> WireFormat for BinaryHeap<V>
Available on crate feature std only.
impl<V> WireFormat for BinaryHeap<V>
Available on crate feature
std only.impl<V> WireFormat for BTreeSet<V>
impl<V> WireFormat for BTreeSet<V>
impl<V> WireFormat for VecDeque<V>
impl<V> WireFormat for VecDeque<V>
Implementors
impl WireFormat for Dirent
impl WireFormat for Qid
impl WireFormat for Rattach
impl WireFormat for Rauth
impl WireFormat for jetstream::p9::Rerror
impl WireFormat for Rframe
impl WireFormat for Rgetattr
impl WireFormat for Rgetlock
impl WireFormat for Rlcreate
impl WireFormat for jetstream::p9::Rlerror
impl WireFormat for Rlock
impl WireFormat for Rlopen
impl WireFormat for Rmkdir
impl WireFormat for Rmknod
impl WireFormat for Rread
impl WireFormat for Rreaddir
impl WireFormat for Rreadlink
impl WireFormat for Rstatfs
impl WireFormat for Rsymlink
impl WireFormat for jetstream::p9::Rversion
impl WireFormat for Rwalk
impl WireFormat for Rwrite
impl WireFormat for Rxattrwalk
impl WireFormat for Tattach
impl WireFormat for Tauth
impl WireFormat for Tclunk
impl WireFormat for Tflush
impl WireFormat for Tframe
impl WireFormat for Tfsync
impl WireFormat for Tgetattr
impl WireFormat for Tgetlock
impl WireFormat for Tlcreate
impl WireFormat for Tlink
impl WireFormat for Tlock
impl WireFormat for Tlopen
impl WireFormat for Tmkdir
impl WireFormat for Tmknod
impl WireFormat for Tread
impl WireFormat for Treaddir
impl WireFormat for Treadlink
impl WireFormat for Tremove
impl WireFormat for Trename
impl WireFormat for Trenameat
impl WireFormat for Tsetattr
impl WireFormat for Tstatfs
impl WireFormat for Tsymlink
impl WireFormat for Tunlinkat
impl WireFormat for jetstream::p9::Tversion
impl WireFormat for Twalk
impl WireFormat for Twrite
impl WireFormat for Txattrcreate
impl WireFormat for Txattrwalk
impl WireFormat for Data
impl WireFormat for jetstream::prelude::Rversion
impl WireFormat for jetstream::prelude::Tversion
impl WireFormat for P9String
impl<T> WireFormat for Frame<T>where
T: Framer,
impl<T, I> WireFormat for Wrapped<T, I>
Available on non-WebAssembly only.